@@ -15,7 +15,7 @@ from pytest_benchmark.utils import parse_warmup
 
 pytest_plugins = 'pytester',
 
-f1 = lambda a: a
+f1 = lambda a: a  # noqa
 
 
 def f2(a):
@@ -84,7 +84,11 @@ def test_missing_scm_bins(scm, crazytestdir, monkeypatch):
     subprocess.check_call([scm, 'commit', '-m', 'asdf'])
     monkeypatch.setenv('PATH', os.getcwd())
     out = get_commit_info()
-    assert 'No such file or directory' in out['error']
+    assert (
+        'No such file or directory' in out['error'] or
+        'The system cannot find the file specified' in out['error'] or
+        'FileNotFoundError' in out['error']
+    )
 
 
 def test_get_branch_info(scm, testdir):
@@ -119,9 +123,8 @@ def test_no_branch_info(testdir):
 def test_commit_info_error(testdir):
     testdir.mkdir('.git')
     info = get_commit_info()
-    assert info['branch'] == '(unknown)'
-    assert info['error'] == 'CalledProcessError(128, ' \
-                            '\'fatal: Not a git repository (or any of the parent directories): .git\\n\')'
+    assert info['branch'].lower() == '(unknown)'.lower()
+    assert info['error'].lower().startswith("calledprocesserror(128, 'fatal: not a git repository")
 
 
 def test_parse_warmup():
@@ -179,16 +182,32 @@ def test_get_project_name_broken(scm, testdir):
     assert get_project_name() in ['test_get_project_name_broken0', 'test_get_project_name_broken1']
 
 
+def test_get_project_name_fallback(testdir, capfd):
+    testdir.tmpdir.ensure('.hg', dir=1)
+    project_name = get_project_name()
+    assert project_name.startswith("test_get_project_name_fallback")
+    assert capfd.readouterr() == ('', '')
+
+
+def test_get_project_name_fallback_broken_hgrc(testdir, capfd):
+    testdir.tmpdir.ensure('.hg', 'hgrc').write('[paths]\ndefault = /')
+    project_name = get_project_name()
+    assert project_name.startswith("test_get_project_name_fallback")
+    assert capfd.readouterr() == ('', '')
+
+
 def test_parse_elasticsearch_storage():
+    benchdir = os.path.basename(os.getcwd())
+
     assert parse_elasticsearch_storage("http://localhost:9200") == (
-    ["http://localhost:9200"], "benchmark", "benchmark", "pytest-benchmark")
+        ["http://localhost:9200"], "benchmark", "benchmark", benchdir)
     assert parse_elasticsearch_storage("http://localhost:9200/benchmark2") == (
-    ["http://localhost:9200"], "benchmark2", "benchmark", "pytest-benchmark")
+        ["http://localhost:9200"], "benchmark2", "benchmark", benchdir)
     assert parse_elasticsearch_storage("http://localhost:9200/benchmark2/benchmark2") == (
-    ["http://localhost:9200"], "benchmark2", "benchmark2", "pytest-benchmark")
+        ["http://localhost:9200"], "benchmark2", "benchmark2", benchdir)
     assert parse_elasticsearch_storage("http://host1:9200,host2:9200") == (
-    ["http://host1:9200", "http://host2:9200"], "benchmark", "benchmark", "pytest-benchmark")
+        ["http://host1:9200", "http://host2:9200"], "benchmark", "benchmark", benchdir)
     assert parse_elasticsearch_storage("http://host1:9200,host2:9200/benchmark2") == (
-    ["http://host1:9200", "http://host2:9200"], "benchmark2", "benchmark", "pytest-benchmark")
+        ["http://host1:9200", "http://host2:9200"], "benchmark2", "benchmark", benchdir)
     assert parse_elasticsearch_storage("http://localhost:9200/benchmark2/benchmark2?project_name=project_name") == (
-    ["http://localhost:9200"], "benchmark2", "benchmark2", "project_name")
+        ["http://localhost:9200"], "benchmark2", "benchmark2", "project_name")
